"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const build_utils_1 = require("@now/build-utils");
exports.shouldServe = build_utils_1.shouldServe;
const lib_1 = require("@now-bref/lib");
const utils_1 = require("./utils");
// ###########################
// EXPORTS
// ###########################
async function build({ files, entrypoint, workPath, config = {}, meta = {}, }) {
    // Collect included files
    let includedFiles = await utils_1.getIncludedFiles({ files, entrypoint, workPath, config, meta });
    // Try to install composer deps only on lambda,
    // not in the local now dev mode.
    if (!meta.isDev) {
        // Composer is called only if composer.json is provided,
        // or config.composer is TRUE
        if (includedFiles['composer.json'] || config.compose === true) {
            includedFiles = { ...includedFiles, ...await utils_1.getComposerFiles(workPath) };
        }
    }
    // Move all user files to LAMBDA_ROOT/user folder.
    const userFiles = build_utils_1.rename(includedFiles, name => path_1.default.join('user', name));
    const bridgeFiles = {
        ...await lib_1.getBrefFiles(),
        ...{
            'bootstrap': new build_utils_1.FileFsRef({
                mode: 0o755,
                fsPath: path_1.default.join(__dirname, '../lib/bootstrap'),
            }),
        }
    };
    if (process.env.NOW_PHP_DEBUG === '1') {
        console.log('🐘 Entrypoint:', entrypoint);
        console.log('🐘 Config:', config);
        console.log('🐘 Work path:', workPath);
        console.log('🐘 Meta:', meta);
        console.log('🐘 User files:', Object.keys(userFiles));
        console.log('🐘 Bridge files:', Object.keys(bridgeFiles));
    }
    const lambda = await build_utils_1.createLambda({
        files: {
            ...userFiles,
            ...bridgeFiles
        },
        handler: entrypoint,
        runtime: 'provided',
        environment: {
            PHP_INI_SCAN_DIR: '/var/task/native/bref/etc/php/conf.d'
        },
    });
    return { [entrypoint]: lambda };
}
exports.build = build;
;
